# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class Network(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active_state': 'str',
        'data_center_id': 'str',
        'external_ip_address': 'str',
        'gateway': 'str',
        'id': 'str',
        'init_state': 'str',
        'internal_ip_address': 'str',
        'ip_range': 'str',
        'network_state': 'NetworkState',
        'price_hr': 'Decimal',
        'short_state': 'str',
        'size': 'VRouterSize'
    }

    attribute_map = {
        'active_state': 'activeState',
        'data_center_id': 'dataCenterId',
        'external_ip_address': 'externalIpAddress',
        'gateway': 'gateway',
        'id': 'id',
        'init_state': 'initState',
        'internal_ip_address': 'internalIpAddress',
        'ip_range': 'ipRange',
        'network_state': 'networkState',
        'price_hr': 'priceHr',
        'short_state': 'shortState',
        'size': 'size'
    }

    def __init__(self, active_state=None, data_center_id=None, external_ip_address=None, gateway=None, id=None, init_state=None, internal_ip_address=None, ip_range=None, network_state=None, price_hr=None, short_state=None, size=None, _configuration=None):  # noqa: E501
        """Network - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active_state = None
        self._data_center_id = None
        self._external_ip_address = None
        self._gateway = None
        self._id = None
        self._init_state = None
        self._internal_ip_address = None
        self._ip_range = None
        self._network_state = None
        self._price_hr = None
        self._short_state = None
        self._size = None
        self.discriminator = None

        if active_state is not None:
            self.active_state = active_state
        if data_center_id is not None:
            self.data_center_id = data_center_id
        if external_ip_address is not None:
            self.external_ip_address = external_ip_address
        if gateway is not None:
            self.gateway = gateway
        if id is not None:
            self.id = id
        if init_state is not None:
            self.init_state = init_state
        if internal_ip_address is not None:
            self.internal_ip_address = internal_ip_address
        if ip_range is not None:
            self.ip_range = ip_range
        if network_state is not None:
            self.network_state = network_state
        if price_hr is not None:
            self.price_hr = price_hr
        if short_state is not None:
            self.short_state = short_state
        if size is not None:
            self.size = size

    @property
    def active_state(self):
        """Gets the active_state of this Network.  # noqa: E501


        :return: The active_state of this Network.  # noqa: E501
        :rtype: str
        """
        return self._active_state

    @active_state.setter
    def active_state(self, active_state):
        """Sets the active_state of this Network.


        :param active_state: The active_state of this Network.  # noqa: E501
        :type: str
        """

        self._active_state = active_state

    @property
    def data_center_id(self):
        """Gets the data_center_id of this Network.  # noqa: E501


        :return: The data_center_id of this Network.  # noqa: E501
        :rtype: str
        """
        return self._data_center_id

    @data_center_id.setter
    def data_center_id(self, data_center_id):
        """Sets the data_center_id of this Network.


        :param data_center_id: The data_center_id of this Network.  # noqa: E501
        :type: str
        """

        self._data_center_id = data_center_id

    @property
    def external_ip_address(self):
        """Gets the external_ip_address of this Network.  # noqa: E501


        :return: The external_ip_address of this Network.  # noqa: E501
        :rtype: str
        """
        return self._external_ip_address

    @external_ip_address.setter
    def external_ip_address(self, external_ip_address):
        """Sets the external_ip_address of this Network.


        :param external_ip_address: The external_ip_address of this Network.  # noqa: E501
        :type: str
        """

        self._external_ip_address = external_ip_address

    @property
    def gateway(self):
        """Gets the gateway of this Network.  # noqa: E501


        :return: The gateway of this Network.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this Network.


        :param gateway: The gateway of this Network.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def id(self):
        """Gets the id of this Network.  # noqa: E501


        :return: The id of this Network.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Network.


        :param id: The id of this Network.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def init_state(self):
        """Gets the init_state of this Network.  # noqa: E501


        :return: The init_state of this Network.  # noqa: E501
        :rtype: str
        """
        return self._init_state

    @init_state.setter
    def init_state(self, init_state):
        """Sets the init_state of this Network.


        :param init_state: The init_state of this Network.  # noqa: E501
        :type: str
        """

        self._init_state = init_state

    @property
    def internal_ip_address(self):
        """Gets the internal_ip_address of this Network.  # noqa: E501


        :return: The internal_ip_address of this Network.  # noqa: E501
        :rtype: str
        """
        return self._internal_ip_address

    @internal_ip_address.setter
    def internal_ip_address(self, internal_ip_address):
        """Sets the internal_ip_address of this Network.


        :param internal_ip_address: The internal_ip_address of this Network.  # noqa: E501
        :type: str
        """

        self._internal_ip_address = internal_ip_address

    @property
    def ip_range(self):
        """Gets the ip_range of this Network.  # noqa: E501


        :return: The ip_range of this Network.  # noqa: E501
        :rtype: str
        """
        return self._ip_range

    @ip_range.setter
    def ip_range(self, ip_range):
        """Sets the ip_range of this Network.


        :param ip_range: The ip_range of this Network.  # noqa: E501
        :type: str
        """

        self._ip_range = ip_range

    @property
    def network_state(self):
        """Gets the network_state of this Network.  # noqa: E501


        :return: The network_state of this Network.  # noqa: E501
        :rtype: NetworkState
        """
        return self._network_state

    @network_state.setter
    def network_state(self, network_state):
        """Sets the network_state of this Network.


        :param network_state: The network_state of this Network.  # noqa: E501
        :type: NetworkState
        """

        self._network_state = network_state

    @property
    def price_hr(self):
        """Gets the price_hr of this Network.  # noqa: E501


        :return: The price_hr of this Network.  # noqa: E501
        :rtype: Decimal
        """
        return self._price_hr

    @price_hr.setter
    def price_hr(self, price_hr):
        """Sets the price_hr of this Network.


        :param price_hr: The price_hr of this Network.  # noqa: E501
        :type: Decimal
        """

        self._price_hr = price_hr

    @property
    def short_state(self):
        """Gets the short_state of this Network.  # noqa: E501


        :return: The short_state of this Network.  # noqa: E501
        :rtype: str
        """
        return self._short_state

    @short_state.setter
    def short_state(self, short_state):
        """Sets the short_state of this Network.


        :param short_state: The short_state of this Network.  # noqa: E501
        :type: str
        """

        self._short_state = short_state

    @property
    def size(self):
        """Gets the size of this Network.  # noqa: E501


        :return: The size of this Network.  # noqa: E501
        :rtype: VRouterSize
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Network.


        :param size: The size of this Network.  # noqa: E501
        :type: VRouterSize
        """

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Network, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Network):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Network):
            return True

        return self.to_dict() != other.to_dict()



from cudo_compute import cudo_api
from cudo_compute.rest import ApiException
import json


def machine_types(gpu_model, mem_gib, vcpu_count, gpu_count):
    try:
        api = cudo_api.virtual_machines()
        types = api.list_vm_machine_types(mem_gib, vcpu_count, gpu=gpu_count, gpu_model=gpu_model)
        types_dict = types.to_dict()
        return types_dict['host_configs']
    except ApiException as e:
        raise e


def gpu_types(gpu_count):
    try:
        api = cudo_api.virtual_machines()
        types = api.list_vm_machine_types(1, 1, gpu=gpu_count, )
        gpu_list = []
        for gpu in types.to_dict()['gpu_models']:
            gpu_list.append(gpu['name'])
        return gpu_list
    except ApiException as e:
        raise e


print('Gpu types')
print(json.dumps(gpu_types(1), indent=2))

print('Machine types with GPU')
mts = machine_types("", 1, 1, 1)
mt_list = []
for mt in mts:
    mt_list.append(
        {'machine_type': mt['machine_type'], 'gpu_model': mt['gpu_model'], 'data_center_id': mt['data_center_id']})
print(json.dumps(mt_list, indent=2))

print('Machine types without GPU')
mts = machine_types("", 1, 1, 0)
mt_list = []
for mt in mts:
    mt_list.append(
        {'machine_type': mt['machine_type'], 'data_center_id': mt['data_center_id']})
print(json.dumps(mt_list, indent=2))



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cudo_compute.api_client import ApiClient


class DataCentersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def count_hosts(self, data_center_id, **kwargs):  # noqa: E501
        """Get host count  # noqa: E501

        Returns the number of hosts in a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_hosts(data_center_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :return: CountHostsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.count_hosts_with_http_info(data_center_id, **kwargs)  # noqa: E501
        else:
            (data) = self.count_hosts_with_http_info(data_center_id, **kwargs)  # noqa: E501
            return data

    def count_hosts_with_http_info(self, data_center_id, **kwargs):  # noqa: E501
        """Get host count  # noqa: E501

        Returns the number of hosts in a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_hosts_with_http_info(data_center_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :return: CountHostsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_center_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count_hosts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_center_id' is set
        if self.api_client.client_side_validation and ('data_center_id' not in params or
                                                       params['data_center_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `data_center_id` when calling `count_hosts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_center_id' in params:
            path_params['dataCenterId'] = params['data_center_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{dataCenterId}/host-count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CountHostsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_data_center(self, data_center, **kwargs):  # noqa: E501
        """Create data center  # noqa: E501

        Creates a new data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_center(data_center, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DataCenter data_center: (required)
        :return: DataCenter
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_data_center_with_http_info(data_center, **kwargs)  # noqa: E501
        else:
            (data) = self.create_data_center_with_http_info(data_center, **kwargs)  # noqa: E501
            return data

    def create_data_center_with_http_info(self, data_center, **kwargs):  # noqa: E501
        """Create data center  # noqa: E501

        Creates a new data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_center_with_http_info(data_center, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DataCenter data_center: (required)
        :return: DataCenter
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_center']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_data_center" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_center' is set
        if self.api_client.client_side_validation and ('data_center' not in params or
                                                       params['data_center'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `data_center` when calling `create_data_center`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data_center' in params:
            body_params = params['data_center']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DataCenter',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_data_center(self, id, **kwargs):  # noqa: E501
        """Delete data center  # noqa: E501

        Deletes a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_center(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_data_center_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_data_center_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_data_center_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete data center  # noqa: E501

        Deletes a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_center_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data_center" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_data_center`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_center(self, id, **kwargs):  # noqa: E501
        """Get data center  # noqa: E501

        Returns a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: DataCenter
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_center_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_center_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_data_center_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get data center  # noqa: E501

        Returns a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: DataCenter
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_center" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_data_center`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DataCenter',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_center_live_utilization(self, id, **kwargs):  # noqa: E501
        """Get live utilization  # noqa: E501

        Returns the live utilization of a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_live_utilization(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: GetDataCenterLiveUtilizationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_center_live_utilization_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_center_live_utilization_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_data_center_live_utilization_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get live utilization  # noqa: E501

        Returns the live utilization of a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_live_utilization_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: GetDataCenterLiveUtilizationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_center_live_utilization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_data_center_live_utilization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{id}/live-utilization', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDataCenterLiveUtilizationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_center_revenue_by_resource(self, id, start_time, end_time, **kwargs):  # noqa: E501
        """Get revenue by resource  # noqa: E501

        Returns the revenue of a data center by resource (CPU, Memory, Storage, etc.)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_revenue_by_resource(id, start_time, end_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param datetime start_time: (required)
        :param datetime end_time: (required)
        :return: GetDataCenterRevenueByResourceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_center_revenue_by_resource_with_http_info(id, start_time, end_time, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_center_revenue_by_resource_with_http_info(id, start_time, end_time, **kwargs)  # noqa: E501
            return data

    def get_data_center_revenue_by_resource_with_http_info(self, id, start_time, end_time, **kwargs):  # noqa: E501
        """Get revenue by resource  # noqa: E501

        Returns the revenue of a data center by resource (CPU, Memory, Storage, etc.)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_revenue_by_resource_with_http_info(id, start_time, end_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param datetime start_time: (required)
        :param datetime end_time: (required)
        :return: GetDataCenterRevenueByResourceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'start_time', 'end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_center_revenue_by_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_data_center_revenue_by_resource`")  # noqa: E501
        # verify the required parameter 'start_time' is set
        if self.api_client.client_side_validation and ('start_time' not in params or
                                                       params['start_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `start_time` when calling `get_data_center_revenue_by_resource`")  # noqa: E501
        # verify the required parameter 'end_time' is set
        if self.api_client.client_side_validation and ('end_time' not in params or
                                                       params['end_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `end_time` when calling `get_data_center_revenue_by_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{id}/revenue-by-resource', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDataCenterRevenueByResourceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_data_center_revenue_time_series(self, id, start_time, end_time, interval, **kwargs):  # noqa: E501
        """Get revenue time series  # noqa: E501

        Returns the revenue of a data center over time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_revenue_time_series(id, start_time, end_time, interval, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param datetime start_time: (required)
        :param datetime end_time: (required)
        :param str interval: (required)
        :return: GetDataCenterRevenueTimeSeriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_data_center_revenue_time_series_with_http_info(id, start_time, end_time, interval, **kwargs)  # noqa: E501
        else:
            (data) = self.get_data_center_revenue_time_series_with_http_info(id, start_time, end_time, interval, **kwargs)  # noqa: E501
            return data

    def get_data_center_revenue_time_series_with_http_info(self, id, start_time, end_time, interval, **kwargs):  # noqa: E501
        """Get revenue time series  # noqa: E501

        Returns the revenue of a data center over time  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_data_center_revenue_time_series_with_http_info(id, start_time, end_time, interval, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param datetime start_time: (required)
        :param datetime end_time: (required)
        :param str interval: (required)
        :return: GetDataCenterRevenueTimeSeriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'start_time', 'end_time', 'interval']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_center_revenue_time_series" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_data_center_revenue_time_series`")  # noqa: E501
        # verify the required parameter 'start_time' is set
        if self.api_client.client_side_validation and ('start_time' not in params or
                                                       params['start_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `start_time` when calling `get_data_center_revenue_time_series`")  # noqa: E501
        # verify the required parameter 'end_time' is set
        if self.api_client.client_side_validation and ('end_time' not in params or
                                                       params['end_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `end_time` when calling `get_data_center_revenue_time_series`")  # noqa: E501
        # verify the required parameter 'interval' is set
        if self.api_client.client_side_validation and ('interval' not in params or
                                                       params['interval'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `interval` when calling `get_data_center_revenue_time_series`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501
        if 'interval' in params:
            query_params.append(('interval', params['interval']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{id}/revenue', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDataCenterRevenueTimeSeriesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_clusters(self, data_center_id, **kwargs):  # noqa: E501
        """List clusters  # noqa: E501

        Returns the clusters in a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_clusters(data_center_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :return: ListClustersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_clusters_with_http_info(data_center_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_clusters_with_http_info(data_center_id, **kwargs)  # noqa: E501
            return data

    def list_clusters_with_http_info(self, data_center_id, **kwargs):  # noqa: E501
        """List clusters  # noqa: E501

        Returns the clusters in a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_clusters_with_http_info(data_center_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :return: ListClustersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_center_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_clusters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_center_id' is set
        if self.api_client.client_side_validation and ('data_center_id' not in params or
                                                       params['data_center_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `data_center_id` when calling `list_clusters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_center_id' in params:
            path_params['dataCenterId'] = params['data_center_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{dataCenterId}/clusters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListClustersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_data_centers(self, **kwargs):  # noqa: E501
        """List data centers  # noqa: E501

        Returns the data centers in an organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_centers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token:
        :param int page_size:
        :return: ListDataCentersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_data_centers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_data_centers_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_data_centers_with_http_info(self, **kwargs):  # noqa: E501
        """List data centers  # noqa: E501

        Returns the data centers in an organization  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_centers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token:
        :param int page_size:
        :return: ListDataCentersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_data_centers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDataCentersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_hosts(self, data_center_id, **kwargs):  # noqa: E501
        """List hosts  # noqa: E501

        Returns the hosts in a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_hosts(data_center_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :return: ListHostsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_hosts_with_http_info(data_center_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_hosts_with_http_info(data_center_id, **kwargs)  # noqa: E501
            return data

    def list_hosts_with_http_info(self, data_center_id, **kwargs):  # noqa: E501
        """List hosts  # noqa: E501

        Returns the hosts in a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_hosts_with_http_info(data_center_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :return: ListHostsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_center_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_hosts" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_center_id' is set
        if self.api_client.client_side_validation and ('data_center_id' not in params or
                                                       params['data_center_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `data_center_id` when calling `list_hosts`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_center_id' in params:
            path_params['dataCenterId'] = params['data_center_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{dataCenterId}/hosts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListHostsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_data_center(self, data_center_id, data_center, **kwargs):  # noqa: E501
        """Update data center  # noqa: E501

        Updates a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_center(data_center_id, data_center, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :param DataCenter data_center: (required)
        :return: DataCenter
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_data_center_with_http_info(data_center_id, data_center, **kwargs)  # noqa: E501
        else:
            (data) = self.update_data_center_with_http_info(data_center_id, data_center, **kwargs)  # noqa: E501
            return data

    def update_data_center_with_http_info(self, data_center_id, data_center, **kwargs):  # noqa: E501
        """Update data center  # noqa: E501

        Updates a data center  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_data_center_with_http_info(data_center_id, data_center, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_center_id: (required)
        :param DataCenter data_center: (required)
        :return: DataCenter
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data_center_id', 'data_center']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_data_center" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'data_center_id' is set
        if self.api_client.client_side_validation and ('data_center_id' not in params or
                                                       params['data_center_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `data_center_id` when calling `update_data_center`")  # noqa: E501
        # verify the required parameter 'data_center' is set
        if self.api_client.client_side_validation and ('data_center' not in params or
                                                       params['data_center'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `data_center` when calling `update_data_center`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'data_center_id' in params:
            path_params['dataCenter.id'] = params['data_center_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data_center' in params:
            body_params = params['data_center']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/data-centers/{dataCenter.id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DataCenter',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from cudo_compute import cudo_api, Disk, CreateVMBody
from cudo_compute.rest import ApiException
import json

# Hint: use examples/machine-types.py to find machine_type/data_center_id and gpu_model
# use examples/images.py to get list of OS images for boot_disk_image_id

try:
    disk = Disk(storage_class="STORAGE_CLASS_NETWORK", size_gib=100,
                id="my-disk-id")
    request = CreateVMBody(vm_id="my-vm-id", machine_type="epyc-rome-rtx-a4000",
                           data_center_id="no-luster-1", boot_disk_image_id='ubuntu-nvidia-docker',
                           memory_gib=16, vcpus=4, gpus=1, gpu_model="A4000", boot_disk=disk,
                           metadata={"group": "a"})
    api = cudo_api.virtual_machines()
    vm = api.create_vm(cudo_api.project_id(), request)

    print(json.dumps(vm.to_dict(), indent=2))
except ApiException as e:
    print(e)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.api_keys_api import APIKeysApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestAPIKeysApi(unittest.TestCase):
    """APIKeysApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.api_keys_api.APIKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Delete  # noqa: E501
        """
        pass

    def test_generate_api_key(self):
        """Test case for generate_api_key

        Generate  # noqa: E501
        """
        pass

    def test_list_api_keys(self):
        """Test case for list_api_keys

        List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.models.list_private_vm_images_response_private_image import ListPrivateVMImagesResponsePrivateImage  # noqa: E501
from cudo_compute.rest import ApiException


class TestListPrivateVMImagesResponsePrivateImage(unittest.TestCase):
    """ListPrivateVMImagesResponsePrivateImage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListPrivateVMImagesResponsePrivateImage(self):
        """Test ListPrivateVMImagesResponsePrivateImage"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cudo_compute.models.list_private_vm_images_response_private_image.ListPrivateVMImagesResponsePrivateImage()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class BillingAccountSpendRow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'Decimal',
        'description': 'str',
        'project_id': 'str',
        'quantity': 'float',
        'unit': 'Unit',
        'unit_amount': 'Decimal'
    }

    attribute_map = {
        'amount': 'amount',
        'description': 'description',
        'project_id': 'projectId',
        'quantity': 'quantity',
        'unit': 'unit',
        'unit_amount': 'unitAmount'
    }

    def __init__(self, amount=None, description=None, project_id=None, quantity=None, unit=None, unit_amount=None, _configuration=None):  # noqa: E501
        """BillingAccountSpendRow - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._amount = None
        self._description = None
        self._project_id = None
        self._quantity = None
        self._unit = None
        self._unit_amount = None
        self.discriminator = None

        self.amount = amount
        self.description = description
        self.project_id = project_id
        self.quantity = quantity
        self.unit = unit
        self.unit_amount = unit_amount

    @property
    def amount(self):
        """Gets the amount of this BillingAccountSpendRow.  # noqa: E501


        :return: The amount of this BillingAccountSpendRow.  # noqa: E501
        :rtype: Decimal
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BillingAccountSpendRow.


        :param amount: The amount of this BillingAccountSpendRow.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and amount is None:
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def description(self):
        """Gets the description of this BillingAccountSpendRow.  # noqa: E501


        :return: The description of this BillingAccountSpendRow.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BillingAccountSpendRow.


        :param description: The description of this BillingAccountSpendRow.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def project_id(self):
        """Gets the project_id of this BillingAccountSpendRow.  # noqa: E501


        :return: The project_id of this BillingAccountSpendRow.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this BillingAccountSpendRow.


        :param project_id: The project_id of this BillingAccountSpendRow.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def quantity(self):
        """Gets the quantity of this BillingAccountSpendRow.  # noqa: E501


        :return: The quantity of this BillingAccountSpendRow.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this BillingAccountSpendRow.


        :param quantity: The quantity of this BillingAccountSpendRow.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and quantity is None:
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501

        self._quantity = quantity

    @property
    def unit(self):
        """Gets the unit of this BillingAccountSpendRow.  # noqa: E501


        :return: The unit of this BillingAccountSpendRow.  # noqa: E501
        :rtype: Unit
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this BillingAccountSpendRow.


        :param unit: The unit of this BillingAccountSpendRow.  # noqa: E501
        :type: Unit
        """
        if self._configuration.client_side_validation and unit is None:
            raise ValueError("Invalid value for `unit`, must not be `None`")  # noqa: E501

        self._unit = unit

    @property
    def unit_amount(self):
        """Gets the unit_amount of this BillingAccountSpendRow.  # noqa: E501


        :return: The unit_amount of this BillingAccountSpendRow.  # noqa: E501
        :rtype: Decimal
        """
        return self._unit_amount

    @unit_amount.setter
    def unit_amount(self, unit_amount):
        """Sets the unit_amount of this BillingAccountSpendRow.


        :param unit_amount: The unit_amount of this BillingAccountSpendRow.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and unit_amount is None:
            raise ValueError("Invalid value for `unit_amount`, must not be `None`")  # noqa: E501

        self._unit_amount = unit_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BillingAccountSpendRow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingAccountSpendRow):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BillingAccountSpendRow):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class PaymentMethodCard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brand': 'str',
        'country': 'str',
        'exp_month': 'str',
        'exp_year': 'str',
        'fingerprint': 'str',
        'last4': 'str'
    }

    attribute_map = {
        'brand': 'brand',
        'country': 'country',
        'exp_month': 'expMonth',
        'exp_year': 'expYear',
        'fingerprint': 'fingerprint',
        'last4': 'last4'
    }

    def __init__(self, brand=None, country=None, exp_month=None, exp_year=None, fingerprint=None, last4=None, _configuration=None):  # noqa: E501
        """PaymentMethodCard - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._brand = None
        self._country = None
        self._exp_month = None
        self._exp_year = None
        self._fingerprint = None
        self._last4 = None
        self.discriminator = None

        if brand is not None:
            self.brand = brand
        if country is not None:
            self.country = country
        if exp_month is not None:
            self.exp_month = exp_month
        if exp_year is not None:
            self.exp_year = exp_year
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if last4 is not None:
            self.last4 = last4

    @property
    def brand(self):
        """Gets the brand of this PaymentMethodCard.  # noqa: E501


        :return: The brand of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this PaymentMethodCard.


        :param brand: The brand of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def country(self):
        """Gets the country of this PaymentMethodCard.  # noqa: E501


        :return: The country of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this PaymentMethodCard.


        :param country: The country of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def exp_month(self):
        """Gets the exp_month of this PaymentMethodCard.  # noqa: E501


        :return: The exp_month of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._exp_month

    @exp_month.setter
    def exp_month(self, exp_month):
        """Sets the exp_month of this PaymentMethodCard.


        :param exp_month: The exp_month of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._exp_month = exp_month

    @property
    def exp_year(self):
        """Gets the exp_year of this PaymentMethodCard.  # noqa: E501


        :return: The exp_year of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._exp_year

    @exp_year.setter
    def exp_year(self, exp_year):
        """Sets the exp_year of this PaymentMethodCard.


        :param exp_year: The exp_year of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._exp_year = exp_year

    @property
    def fingerprint(self):
        """Gets the fingerprint of this PaymentMethodCard.  # noqa: E501


        :return: The fingerprint of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this PaymentMethodCard.


        :param fingerprint: The fingerprint of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def last4(self):
        """Gets the last4 of this PaymentMethodCard.  # noqa: E501


        :return: The last4 of this PaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """Sets the last4 of this PaymentMethodCard.


        :param last4: The last4 of this PaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._last4 = last4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentMethodCard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentMethodCard):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentMethodCard):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.billing_api import BillingApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestBillingApi(unittest.TestCase):
    """BillingApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.billing_api.BillingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_billing_account(self):
        """Test case for create_billing_account

        Create a billing account  # noqa: E501
        """
        pass

    def test_delete_billing_account(self):
        """Test case for delete_billing_account

        Delete billing account  # noqa: E501
        """
        pass

    def test_get_billing_account(self):
        """Test case for get_billing_account

        Get a billing account  # noqa: E501
        """
        pass

    def test_get_billing_account_details(self):
        """Test case for get_billing_account_details

        Get billing account details  # noqa: E501
        """
        pass

    def test_get_billing_account_payment_methods(self):
        """Test case for get_billing_account_payment_methods

        Get payment methods  # noqa: E501
        """
        pass

    def test_get_billing_account_setup_intent(self):
        """Test case for get_billing_account_setup_intent

        Get setup intent  # noqa: E501
        """
        pass

    def test_get_billing_account_spend_details(self):
        """Test case for get_billing_account_spend_details

        Get spend details  # noqa: E501
        """
        pass

    def test_get_billing_account_stripe_invoices(self):
        """Test case for get_billing_account_stripe_invoices

        Get invoices  # noqa: E501
        """
        pass

    def test_list_billing_accounts(self):
        """Test case for list_billing_accounts

        List billing accounts  # noqa: E501
        """
        pass

    def test_list_outstanding_stripe_invoices(self):
        """Test case for list_outstanding_stripe_invoices

        Get outstanding invoices  # noqa: E501
        """
        pass

    def test_remove_billing_account_payment_method(self):
        """Test case for remove_billing_account_payment_method

        Remove payment method  # noqa: E501
        """
        pass

    def test_set_billing_account_default_payment_method(self):
        """Test case for set_billing_account_default_payment_method

        Set default payment method  # noqa: E501
        """
        pass

    def test_update_billing_account(self):
        """Test case for update_billing_account

        Update billing account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class Profile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_address': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'picture': 'str'
    }

    attribute_map = {
        'email_address': 'emailAddress',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'picture': 'picture'
    }

    def __init__(self, email_address=None, first_name=None, last_name=None, picture=None, _configuration=None):  # noqa: E501
        """Profile - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email_address = None
        self._first_name = None
        self._last_name = None
        self._picture = None
        self.discriminator = None

        if email_address is not None:
            self.email_address = email_address
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if picture is not None:
            self.picture = picture

    @property
    def email_address(self):
        """Gets the email_address of this Profile.  # noqa: E501


        :return: The email_address of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this Profile.


        :param email_address: The email_address of this Profile.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def first_name(self):
        """Gets the first_name of this Profile.  # noqa: E501


        :return: The first_name of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Profile.


        :param first_name: The first_name of this Profile.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Profile.  # noqa: E501


        :return: The last_name of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Profile.


        :param last_name: The last_name of this Profile.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def picture(self):
        """Gets the picture of this Profile.  # noqa: E501


        :return: The picture of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._picture

    @picture.setter
    def picture(self, picture):
        """Sets the picture of this Profile.


        :param picture: The picture of this Profile.  # noqa: E501
        :type: str
        """

        self._picture = picture

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Profile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Profile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Profile):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.models.list_disk_snapshots_response import ListDiskSnapshotsResponse  # noqa: E501
from cudo_compute.rest import ApiException


class TestListDiskSnapshotsResponse(unittest.TestCase):
    """ListDiskSnapshotsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListDiskSnapshotsResponse(self):
        """Test ListDiskSnapshotsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = cudo_compute.models.list_disk_snapshots_response.ListDiskSnapshotsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class V1billingaccountsbillingAccountIdBillingAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billing_threshold': 'Decimal',
        'create_by': 'str',
        'create_time': 'datetime',
        'demand_enabled': 'bool',
        'display_name': 'str',
        'invoice_time': 'datetime',
        'monthly_spend': 'str',
        'stripe_ref': 'str',
        'supply_enabled': 'bool',
        'tax_ids': 'list[TaxId]'
    }

    attribute_map = {
        'billing_threshold': 'billingThreshold',
        'create_by': 'createBy',
        'create_time': 'createTime',
        'demand_enabled': 'demandEnabled',
        'display_name': 'displayName',
        'invoice_time': 'invoiceTime',
        'monthly_spend': 'monthlySpend',
        'stripe_ref': 'stripeRef',
        'supply_enabled': 'supplyEnabled',
        'tax_ids': 'taxIds'
    }

    def __init__(self, billing_threshold=None, create_by=None, create_time=None, demand_enabled=None, display_name=None, invoice_time=None, monthly_spend=None, stripe_ref=None, supply_enabled=None, tax_ids=None, _configuration=None):  # noqa: E501
        """V1billingaccountsbillingAccountIdBillingAccount - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._billing_threshold = None
        self._create_by = None
        self._create_time = None
        self._demand_enabled = None
        self._display_name = None
        self._invoice_time = None
        self._monthly_spend = None
        self._stripe_ref = None
        self._supply_enabled = None
        self._tax_ids = None
        self.discriminator = None

        if billing_threshold is not None:
            self.billing_threshold = billing_threshold
        if create_by is not None:
            self.create_by = create_by
        if create_time is not None:
            self.create_time = create_time
        if demand_enabled is not None:
            self.demand_enabled = demand_enabled
        if display_name is not None:
            self.display_name = display_name
        if invoice_time is not None:
            self.invoice_time = invoice_time
        if monthly_spend is not None:
            self.monthly_spend = monthly_spend
        if stripe_ref is not None:
            self.stripe_ref = stripe_ref
        if supply_enabled is not None:
            self.supply_enabled = supply_enabled
        if tax_ids is not None:
            self.tax_ids = tax_ids

    @property
    def billing_threshold(self):
        """Gets the billing_threshold of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The billing_threshold of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: Decimal
        """
        return self._billing_threshold

    @billing_threshold.setter
    def billing_threshold(self, billing_threshold):
        """Sets the billing_threshold of this V1billingaccountsbillingAccountIdBillingAccount.


        :param billing_threshold: The billing_threshold of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: Decimal
        """

        self._billing_threshold = billing_threshold

    @property
    def create_by(self):
        """Gets the create_by of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The create_by of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: str
        """
        return self._create_by

    @create_by.setter
    def create_by(self, create_by):
        """Sets the create_by of this V1billingaccountsbillingAccountIdBillingAccount.


        :param create_by: The create_by of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: str
        """

        self._create_by = create_by

    @property
    def create_time(self):
        """Gets the create_time of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The create_time of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this V1billingaccountsbillingAccountIdBillingAccount.


        :param create_time: The create_time of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def demand_enabled(self):
        """Gets the demand_enabled of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The demand_enabled of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: bool
        """
        return self._demand_enabled

    @demand_enabled.setter
    def demand_enabled(self, demand_enabled):
        """Sets the demand_enabled of this V1billingaccountsbillingAccountIdBillingAccount.


        :param demand_enabled: The demand_enabled of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: bool
        """

        self._demand_enabled = demand_enabled

    @property
    def display_name(self):
        """Gets the display_name of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The display_name of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this V1billingaccountsbillingAccountIdBillingAccount.


        :param display_name: The display_name of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def invoice_time(self):
        """Gets the invoice_time of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The invoice_time of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: datetime
        """
        return self._invoice_time

    @invoice_time.setter
    def invoice_time(self, invoice_time):
        """Sets the invoice_time of this V1billingaccountsbillingAccountIdBillingAccount.


        :param invoice_time: The invoice_time of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: datetime
        """

        self._invoice_time = invoice_time

    @property
    def monthly_spend(self):
        """Gets the monthly_spend of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The monthly_spend of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: str
        """
        return self._monthly_spend

    @monthly_spend.setter
    def monthly_spend(self, monthly_spend):
        """Sets the monthly_spend of this V1billingaccountsbillingAccountIdBillingAccount.


        :param monthly_spend: The monthly_spend of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: str
        """

        self._monthly_spend = monthly_spend

    @property
    def stripe_ref(self):
        """Gets the stripe_ref of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The stripe_ref of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: str
        """
        return self._stripe_ref

    @stripe_ref.setter
    def stripe_ref(self, stripe_ref):
        """Sets the stripe_ref of this V1billingaccountsbillingAccountIdBillingAccount.


        :param stripe_ref: The stripe_ref of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: str
        """

        self._stripe_ref = stripe_ref

    @property
    def supply_enabled(self):
        """Gets the supply_enabled of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The supply_enabled of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: bool
        """
        return self._supply_enabled

    @supply_enabled.setter
    def supply_enabled(self, supply_enabled):
        """Sets the supply_enabled of this V1billingaccountsbillingAccountIdBillingAccount.


        :param supply_enabled: The supply_enabled of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: bool
        """

        self._supply_enabled = supply_enabled

    @property
    def tax_ids(self):
        """Gets the tax_ids of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501


        :return: The tax_ids of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :rtype: list[TaxId]
        """
        return self._tax_ids

    @tax_ids.setter
    def tax_ids(self, tax_ids):
        """Sets the tax_ids of this V1billingaccountsbillingAccountIdBillingAccount.


        :param tax_ids: The tax_ids of this V1billingaccountsbillingAccountIdBillingAccount.  # noqa: E501
        :type: list[TaxId]
        """

        self._tax_ids = tax_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1billingaccountsbillingAccountIdBillingAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1billingaccountsbillingAccountIdBillingAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1billingaccountsbillingAccountIdBillingAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cudo_compute.api_client import ApiClient


class BillingApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_billing_account(self, create_billing_account_body, **kwargs):  # noqa: E501
        """Create a billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_billing_account(create_billing_account_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateBillingAccountRequest create_billing_account_body: (required)
        :return: BillingAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_billing_account_with_http_info(create_billing_account_body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_billing_account_with_http_info(create_billing_account_body, **kwargs)  # noqa: E501
            return data

    def create_billing_account_with_http_info(self, create_billing_account_body, **kwargs):  # noqa: E501
        """Create a billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_billing_account_with_http_info(create_billing_account_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateBillingAccountRequest create_billing_account_body: (required)
        :return: BillingAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_billing_account_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_billing_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_billing_account_body' is set
        if self.api_client.client_side_validation and ('create_billing_account_body' not in params or
                                                       params['create_billing_account_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_billing_account_body` when calling `create_billing_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_billing_account_body' in params:
            body_params = params['create_billing_account_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BillingAccount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_billing_account(self, id, **kwargs):  # noqa: E501
        """Delete billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_billing_account(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_billing_account_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_billing_account_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_billing_account_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_billing_account_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_billing_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_billing_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_billing_account(self, id, **kwargs):  # noqa: E501
        """Get a billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: BillingAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_billing_account_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_billing_account_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_billing_account_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: BillingAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_billing_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BillingAccount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_billing_account_details(self, id, **kwargs):  # noqa: E501
        """Get billing account details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_details(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: GetBillingAccountDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_billing_account_details_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_billing_account_details_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_billing_account_details_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get billing account details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_details_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: GetBillingAccountDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_account_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_billing_account_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}/details', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetBillingAccountDetailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_billing_account_payment_methods(self, id, **kwargs):  # noqa: E501
        """Get payment methods  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_payment_methods(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: BillingAccountPaymentMethods
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_billing_account_payment_methods_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_billing_account_payment_methods_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_billing_account_payment_methods_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get payment methods  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_payment_methods_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: BillingAccountPaymentMethods
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_account_payment_methods" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_billing_account_payment_methods`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}/payment-methods', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BillingAccountPaymentMethods',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_billing_account_setup_intent(self, id, **kwargs):  # noqa: E501
        """Get setup intent  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_setup_intent(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: BillingAccountSetupIntent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_billing_account_setup_intent_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_billing_account_setup_intent_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_billing_account_setup_intent_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get setup intent  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_setup_intent_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: BillingAccountSetupIntent
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_account_setup_intent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_billing_account_setup_intent`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}/setup-intent', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BillingAccountSetupIntent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_billing_account_spend_details(self, billing_account_id, start_time, end_time, **kwargs):  # noqa: E501
        """Get spend details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_spend_details(billing_account_id, start_time, end_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str billing_account_id: (required)
        :param datetime start_time: (required)
        :param datetime end_time: (required)
        :return: GetBillingAccountSpendDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_billing_account_spend_details_with_http_info(billing_account_id, start_time, end_time, **kwargs)  # noqa: E501
        else:
            (data) = self.get_billing_account_spend_details_with_http_info(billing_account_id, start_time, end_time, **kwargs)  # noqa: E501
            return data

    def get_billing_account_spend_details_with_http_info(self, billing_account_id, start_time, end_time, **kwargs):  # noqa: E501
        """Get spend details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_spend_details_with_http_info(billing_account_id, start_time, end_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str billing_account_id: (required)
        :param datetime start_time: (required)
        :param datetime end_time: (required)
        :return: GetBillingAccountSpendDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['billing_account_id', 'start_time', 'end_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_account_spend_details" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'billing_account_id' is set
        if self.api_client.client_side_validation and ('billing_account_id' not in params or
                                                       params['billing_account_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `billing_account_id` when calling `get_billing_account_spend_details`")  # noqa: E501
        # verify the required parameter 'start_time' is set
        if self.api_client.client_side_validation and ('start_time' not in params or
                                                       params['start_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `start_time` when calling `get_billing_account_spend_details`")  # noqa: E501
        # verify the required parameter 'end_time' is set
        if self.api_client.client_side_validation and ('end_time' not in params or
                                                       params['end_time'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `end_time` when calling `get_billing_account_spend_details`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'billing_account_id' in params:
            path_params['billingAccountId'] = params['billing_account_id']  # noqa: E501

        query_params = []
        if 'start_time' in params:
            query_params.append(('startTime', params['start_time']))  # noqa: E501
        if 'end_time' in params:
            query_params.append(('endTime', params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{billingAccountId}/spend/details', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetBillingAccountSpendDetailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_billing_account_stripe_invoices(self, id, **kwargs):  # noqa: E501
        """Get invoices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_stripe_invoices(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int page_size:
        :param str starting_after:
        :param str status:
        :return: GetBillingAccountStripeInvoicesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_billing_account_stripe_invoices_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_billing_account_stripe_invoices_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_billing_account_stripe_invoices_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get invoices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_billing_account_stripe_invoices_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param int page_size:
        :param str starting_after:
        :param str status:
        :return: GetBillingAccountStripeInvoicesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'page_size', 'starting_after', 'status']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_billing_account_stripe_invoices" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_billing_account_stripe_invoices`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('id', params['id']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'starting_after' in params:
            query_params.append(('startingAfter', params['starting_after']))  # noqa: E501
        if 'status' in params:
            query_params.append(('status', params['status']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/invoices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetBillingAccountStripeInvoicesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_billing_accounts(self, **kwargs):  # noqa: E501
        """List billing accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_billing_accounts(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token:
        :param int page_size:
        :return: ListBillingAccountsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_billing_accounts_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_billing_accounts_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_billing_accounts_with_http_info(self, **kwargs):  # noqa: E501
        """List billing accounts  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_billing_accounts_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token:
        :param int page_size:
        :return: ListBillingAccountsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_billing_accounts" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListBillingAccountsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_outstanding_stripe_invoices(self, **kwargs):  # noqa: E501
        """Get outstanding invoices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_outstanding_stripe_invoices(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListOutstandingStripeInvoicesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_outstanding_stripe_invoices_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_outstanding_stripe_invoices_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_outstanding_stripe_invoices_with_http_info(self, **kwargs):  # noqa: E501
        """Get outstanding invoices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_outstanding_stripe_invoices_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ListOutstandingStripeInvoicesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_outstanding_stripe_invoices" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/invoices/outstanding', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListOutstandingStripeInvoicesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_billing_account_payment_method(self, id, payment_method_id, **kwargs):  # noqa: E501
        """Remove payment method  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_billing_account_payment_method(id, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str payment_method_id: (required)
        :return: RemoveBillingAccountPaymentMethodResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_billing_account_payment_method_with_http_info(id, payment_method_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_billing_account_payment_method_with_http_info(id, payment_method_id, **kwargs)  # noqa: E501
            return data

    def remove_billing_account_payment_method_with_http_info(self, id, payment_method_id, **kwargs):  # noqa: E501
        """Remove payment method  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_billing_account_payment_method_with_http_info(id, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str payment_method_id: (required)
        :return: RemoveBillingAccountPaymentMethodResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'payment_method_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_billing_account_payment_method" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_billing_account_payment_method`")  # noqa: E501
        # verify the required parameter 'payment_method_id' is set
        if self.api_client.client_side_validation and ('payment_method_id' not in params or
                                                       params['payment_method_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `payment_method_id` when calling `remove_billing_account_payment_method`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'payment_method_id' in params:
            path_params['paymentMethodId'] = params['payment_method_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}/payment-methods/{paymentMethodId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveBillingAccountPaymentMethodResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_billing_account_default_payment_method(self, id, payment_method_id, **kwargs):  # noqa: E501
        """Set default payment method  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_billing_account_default_payment_method(id, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str payment_method_id: (required)
        :return: SetBillingAccountDefaultPaymentMethodResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_billing_account_default_payment_method_with_http_info(id, payment_method_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_billing_account_default_payment_method_with_http_info(id, payment_method_id, **kwargs)  # noqa: E501
            return data

    def set_billing_account_default_payment_method_with_http_info(self, id, payment_method_id, **kwargs):  # noqa: E501
        """Set default payment method  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_billing_account_default_payment_method_with_http_info(id, payment_method_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str payment_method_id: (required)
        :return: SetBillingAccountDefaultPaymentMethodResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'payment_method_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_billing_account_default_payment_method" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `set_billing_account_default_payment_method`")  # noqa: E501
        # verify the required parameter 'payment_method_id' is set
        if self.api_client.client_side_validation and ('payment_method_id' not in params or
                                                       params['payment_method_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `payment_method_id` when calling `set_billing_account_default_payment_method`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501
        if 'payment_method_id' in params:
            path_params['paymentMethodId'] = params['payment_method_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{id}/payment-methods/{paymentMethodId}/set-default', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SetBillingAccountDefaultPaymentMethodResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_billing_account(self, billing_account_id, update_billing_account_body, **kwargs):  # noqa: E501
        """Update billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_billing_account(billing_account_id, update_billing_account_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str billing_account_id: (required)
        :param UpdateBillingAccountBody update_billing_account_body: (required)
        :return: BillingAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_billing_account_with_http_info(billing_account_id, update_billing_account_body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_billing_account_with_http_info(billing_account_id, update_billing_account_body, **kwargs)  # noqa: E501
            return data

    def update_billing_account_with_http_info(self, billing_account_id, update_billing_account_body, **kwargs):  # noqa: E501
        """Update billing account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_billing_account_with_http_info(billing_account_id, update_billing_account_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str billing_account_id: (required)
        :param UpdateBillingAccountBody update_billing_account_body: (required)
        :return: BillingAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['billing_account_id', 'update_billing_account_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_billing_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'billing_account_id' is set
        if self.api_client.client_side_validation and ('billing_account_id' not in params or
                                                       params['billing_account_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `billing_account_id` when calling `update_billing_account`")  # noqa: E501
        # verify the required parameter 'update_billing_account_body' is set
        if self.api_client.client_side_validation and ('update_billing_account_body' not in params or
                                                       params['update_billing_account_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_billing_account_body` when calling `update_billing_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'billing_account_id' in params:
            path_params['billingAccount.id'] = params['billing_account_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_billing_account_body' in params:
            body_params = params['update_billing_account_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing-accounts/{billingAccount.id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BillingAccount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from cudo_compute import cudo_api
from cudo_compute.rest import ApiException
import json

try:
    api = cudo_api.virtual_machines()
    vms = api.list_vms(cudo_api.project_id())
    print(json.dumps(vms.to_dict(), indent=2))
except ApiException as e:
    print(e)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class VMNIC(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'external_ip_address': 'str',
        'internal_ip_address': 'str',
        'network_address': 'str',
        'network_id': 'str',
        'security_group_ids': 'list[str]'
    }

    attribute_map = {
        'external_ip_address': 'externalIpAddress',
        'internal_ip_address': 'internalIpAddress',
        'network_address': 'networkAddress',
        'network_id': 'networkId',
        'security_group_ids': 'securityGroupIds'
    }

    def __init__(self, external_ip_address=None, internal_ip_address=None, network_address=None, network_id=None, security_group_ids=None, _configuration=None):  # noqa: E501
        """VMNIC - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._external_ip_address = None
        self._internal_ip_address = None
        self._network_address = None
        self._network_id = None
        self._security_group_ids = None
        self.discriminator = None

        if external_ip_address is not None:
            self.external_ip_address = external_ip_address
        if internal_ip_address is not None:
            self.internal_ip_address = internal_ip_address
        if network_address is not None:
            self.network_address = network_address
        if network_id is not None:
            self.network_id = network_id
        if security_group_ids is not None:
            self.security_group_ids = security_group_ids

    @property
    def external_ip_address(self):
        """Gets the external_ip_address of this VMNIC.  # noqa: E501


        :return: The external_ip_address of this VMNIC.  # noqa: E501
        :rtype: str
        """
        return self._external_ip_address

    @external_ip_address.setter
    def external_ip_address(self, external_ip_address):
        """Sets the external_ip_address of this VMNIC.


        :param external_ip_address: The external_ip_address of this VMNIC.  # noqa: E501
        :type: str
        """

        self._external_ip_address = external_ip_address

    @property
    def internal_ip_address(self):
        """Gets the internal_ip_address of this VMNIC.  # noqa: E501


        :return: The internal_ip_address of this VMNIC.  # noqa: E501
        :rtype: str
        """
        return self._internal_ip_address

    @internal_ip_address.setter
    def internal_ip_address(self, internal_ip_address):
        """Sets the internal_ip_address of this VMNIC.


        :param internal_ip_address: The internal_ip_address of this VMNIC.  # noqa: E501
        :type: str
        """

        self._internal_ip_address = internal_ip_address

    @property
    def network_address(self):
        """Gets the network_address of this VMNIC.  # noqa: E501


        :return: The network_address of this VMNIC.  # noqa: E501
        :rtype: str
        """
        return self._network_address

    @network_address.setter
    def network_address(self, network_address):
        """Sets the network_address of this VMNIC.


        :param network_address: The network_address of this VMNIC.  # noqa: E501
        :type: str
        """

        self._network_address = network_address

    @property
    def network_id(self):
        """Gets the network_id of this VMNIC.  # noqa: E501


        :return: The network_id of this VMNIC.  # noqa: E501
        :rtype: str
        """
        return self._network_id

    @network_id.setter
    def network_id(self, network_id):
        """Sets the network_id of this VMNIC.


        :param network_id: The network_id of this VMNIC.  # noqa: E501
        :type: str
        """

        self._network_id = network_id

    @property
    def security_group_ids(self):
        """Gets the security_group_ids of this VMNIC.  # noqa: E501


        :return: The security_group_ids of this VMNIC.  # noqa: E501
        :rtype: list[str]
        """
        return self._security_group_ids

    @security_group_ids.setter
    def security_group_ids(self, security_group_ids):
        """Sets the security_group_ids of this VMNIC.


        :param security_group_ids: The security_group_ids of this VMNIC.  # noqa: E501
        :type: list[str]
        """

        self._security_group_ids = security_group_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VMNIC, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VMNIC):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VMNIC):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.virtual_machines_api import VirtualMachinesApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestVirtualMachinesApi(unittest.TestCase):
    """VirtualMachinesApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.virtual_machines_api.VirtualMachinesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_security_group(self):
        """Test case for attach_security_group

        Attach security group to VM  # noqa: E501
        """
        pass

    def test_connect_vm(self):
        """Test case for connect_vm

        Connect via VNC  # noqa: E501
        """
        pass

    def test_count_vms(self):
        """Test case for count_vms

        Count  # noqa: E501
        """
        pass

    def test_create_private_vm_image(self):
        """Test case for create_private_vm_image

        Create private VM image  # noqa: E501
        """
        pass

    def test_create_vm(self):
        """Test case for create_vm

        Create virtual machine  # noqa: E501
        """
        pass

    def test_delete_private_vm_image(self):
        """Test case for delete_private_vm_image

        Delete private VM image  # noqa: E501
        """
        pass

    def test_detach_security_group(self):
        """Test case for detach_security_group

        Attach security group to VM  # noqa: E501
        """
        pass

    def test_get_private_vm_image(self):
        """Test case for get_private_vm_image

        Get private VM image  # noqa: E501
        """
        pass

    def test_get_vm(self):
        """Test case for get_vm

        Get  # noqa: E501
        """
        pass

    def test_list_private_vm_images(self):
        """Test case for list_private_vm_images

        List private VM images  # noqa: E501
        """
        pass

    def test_list_public_vm_images(self):
        """Test case for list_public_vm_images

        List public VM images  # noqa: E501
        """
        pass

    def test_list_vm_data_centers(self):
        """Test case for list_vm_data_centers

        List data centers  # noqa: E501
        """
        pass

    def test_list_vm_disks(self):
        """Test case for list_vm_disks

        List disks attached to VM  # noqa: E501
        """
        pass

    def test_list_vm_machine_types(self):
        """Test case for list_vm_machine_types

        List machine types  # noqa: E501
        """
        pass

    def test_list_vms(self):
        """Test case for list_vms

        List  # noqa: E501
        """
        pass

    def test_monitor_vm(self):
        """Test case for monitor_vm

        Monitor  # noqa: E501
        """
        pass

    def test_reboot_vm(self):
        """Test case for reboot_vm

        Reboot  # noqa: E501
        """
        pass

    def test_resize_vm(self):
        """Test case for resize_vm

        Resize vCPU and memory of VM  # noqa: E501
        """
        pass

    def test_resize_vm_disk(self):
        """Test case for resize_vm_disk

        Resize a VM's disk  # noqa: E501
        """
        pass

    def test_start_vm(self):
        """Test case for start_vm

        Start  # noqa: E501
        """
        pass

    def test_stop_vm(self):
        """Test case for stop_vm

        Stop  # noqa: E501
        """
        pass

    def test_terminate_vm(self):
        """Test case for terminate_vm

        Terminate  # noqa: E501
        """
        pass

    def test_update_private_vm_image(self):
        """Test case for update_private_vm_image

        Update private VM image  # noqa: E501
        """
        pass

    def test_update_vm_metadata(self):
        """Test case for update_vm_metadata

        Update VM metadata  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
